# eric7.WebBrowser.WebBrowserWebAuthDialog

Module implementing a dialog to handle the various WebAuth requests.

### Global Attributes

None

### Classes

WebBrowserWebAuthDialog | Class implementing a dialog to handle the various WebAuth requests.

### Functions

None

## WebBrowserWebAuthDialog

Class implementing a dialog to handle the various WebAuth requests.

### Derived from

QDialog, Ui_WebBrowserWebAuthDialog

### Class Attributes

None

### Class Methods

None

### Methods

WebBrowserWebAuthDialog | Constructor
__acceptRequest | Private slot to accept the WebAuth request.
__cancelRequest | Private slot to cancel the WebAuth request.
__clearSelectAccountButtons | Private method to remove the account selection buttons.
__retry | Private slot to retry the WebAuth request.
__setupCollectPinUi | Private method to configure the 'Collect PIN' UI.
__setupErrorUi | Private method to configure the 'Error' UI.
__setupFinishCollectTokenUi | Private method to configure the 'Finish Collect Token' UI.
__setupSelectAccountUi | Private method to configure the 'Select Account' UI.
on_confirmPinEdit_textEdited | Private slot handling entering of a confirmation PIN.
on_pinButton_toggled | Private slot to handle the toggling of the PIN visibility.
on_pinEdit_textEdited | Private slot handling entering a PIN.
updateDialog | Public slot to update the dialog depending on the current WebAuth request state.

### Static Methods

None

#### WebBrowserWebAuthDialog (Constructor)

WebBrowserWebAuthDialog(uxRequest, parent=None)

Constructor

uxRequest (QWebEngineWebAuthUxRequest)
  reference to the WebAuth request object
parent (QWidget (optional))
  reference to the parent widget (defaults to None)

#### WebBrowserWebAuthDialog.__acceptRequest

__acceptRequest()

Private slot to accept the WebAuth request.

#### WebBrowserWebAuthDialog.__cancelRequest

__cancelRequest()

Private slot to cancel the WebAuth request.

#### WebBrowserWebAuthDialog.__clearSelectAccountButtons

__clearSelectAccountButtons()

Private method to remove the account selection buttons.

#### WebBrowserWebAuthDialog.__retry

__retry()

Private slot to retry the WebAuth request.

#### WebBrowserWebAuthDialog.__setupCollectPinUi

__setupCollectPinUi()

Private method to configure the 'Collect PIN' UI.

#### WebBrowserWebAuthDialog.__setupErrorUi

__setupErrorUi()

Private method to configure the 'Error' UI.

#### WebBrowserWebAuthDialog.__setupFinishCollectTokenUi

__setupFinishCollectTokenUi()

Private method to configure the 'Finish Collect Token' UI.

#### WebBrowserWebAuthDialog.__setupSelectAccountUi

__setupSelectAccountUi()

Private method to configure the 'Select Account' UI.

#### WebBrowserWebAuthDialog.on_confirmPinEdit_textEdited

on_confirmPinEdit_textEdited(pin)

Private slot handling entering of a confirmation PIN.

pin (str)
  entered confirmation PIN

#### WebBrowserWebAuthDialog.on_pinButton_toggled

on_pinButton_toggled(checked)

Private slot to handle the toggling of the PIN visibility.

checked (bool)
  state of the PIN visibility button

#### WebBrowserWebAuthDialog.on_pinEdit_textEdited

on_pinEdit_textEdited(pin)

Private slot handling entering a PIN.

pin (str)
  entered PIN

#### WebBrowserWebAuthDialog.updateDialog

updateDialog()

Public slot to update the dialog depending on the current WebAuth request state.

Up